@@ -5,6 +5,7 @@ import locale
 import json
 import ctypes
 import sys
+import warnings
 from pkg_resources import get_distribution, DistributionNotFound
 import xml.etree.ElementTree as ET
 
@@ -199,7 +200,11 @@ class MediaInfo(object):
                 lib.MediaInfo_Delete.restype  = None
                 lib.MediaInfo_Close.argtypes = [ctypes.c_void_p]
                 lib.MediaInfo_Close.restype = None
-                return lib
+                # Obtain the library version
+                lib_version_str = lib.MediaInfo_Option(None, "Info_Version", "")
+                lib_version_str = re.search(r"^MediaInfoLib - v(\S+)", lib_version_str).group(1)
+                lib_version = tuple(int(_) for _ in lib_version_str.split("."))
+                return (lib, lib_version_str, lib_version)
             except OSError:
                 # If we've tried all possible filenames
                 if i == len(library_names):
@@ -219,7 +224,7 @@ class MediaInfo(object):
     @classmethod
     def parse(cls, filename, library_file=None, cover_data=False,
             encoding_errors="strict", parse_speed=0.5, text=False,
-            full=True, legacy_stream_display=False):
+            full=True, legacy_stream_display=False, mediainfo_options=None):
         """
         Analyze a media file using libmediainfo.
         If libmediainfo is located in a non-standard location, the `library_file` parameter can be used:
@@ -243,6 +248,8 @@ class MediaInfo(object):
         :param bool full: display additional tags, including computer-readable values
             for sizes and durations.
         :param bool legacy_stream_display: display additional information about streams.
+        :param dict mediainfo_options: additional options that will be passed to the `MediaInfo_Option` function,
+            for example: ``{"Language": "raw"}``
         :type filename: str or pathlib.Path
         :rtype: str if `text` is ``True``.
         :rtype: :class:`MediaInfo` otherwise.
@@ -253,7 +260,7 @@ class MediaInfo(object):
         :raises RuntimeError: if parsing fails, this should not
             happen unless libmediainfo itself fails.
         """
-        lib = cls._get_library(library_file)
+        lib, lib_version_str, lib_version = cls._get_library(library_file)
         if pathlib is not None and isinstance(filename, pathlib.PurePath):
             filename = str(filename)
             url = False
@@ -265,9 +272,8 @@ class MediaInfo(object):
             # Test whether the file is readable
             with open(filename, "rb"):
                 pass
-        # Obtain the library version
-        lib_version = lib.MediaInfo_Option(None, "Info_Version", "")
-        lib_version = tuple(int(_) for _ in re.search("^MediaInfoLib - v(\\S+)", lib_version).group(1).split("."))
+        # Create a MediaInfo handle
+        handle = lib.MediaInfo_New()
         # The XML option was renamed starting with version 17.10
         if lib_version >= (17, 10):
             xml_option = "OLDXML"
@@ -275,10 +281,8 @@ class MediaInfo(object):
             xml_option = "XML"
         # Cover_Data is not extracted by default since version 18.03
         # See https://github.com/MediaArea/MediaInfoLib/commit/d8fd88a1c282d1c09388c55ee0b46029e7330690
-        if cover_data and lib_version >= (18, 3):
-            lib.MediaInfo_Option(None, "Cover_Data", "base64")
-        # Create a MediaInfo handle
-        handle = lib.MediaInfo_New()
+        if lib_version >= (18, 3):
+            lib.MediaInfo_Option(handle, "Cover_Data", "base64" if cover_data else "")
         lib.MediaInfo_Option(handle, "CharSet", "UTF-8")
         # Fix for https://github.com/sbraz/pymediainfo/issues/22
         # Python 2 does not change LC_CTYPE
@@ -286,14 +290,28 @@ class MediaInfo(object):
         if (sys.version_info < (3,) and os.name == "posix"
                 and locale.getlocale() == (None, None)):
             locale.setlocale(locale.LC_CTYPE, locale.getdefaultlocale())
-        lib.MediaInfo_Option(None, "Inform", "" if text else xml_option)
-        lib.MediaInfo_Option(None, "Complete", "1" if full else "")
-        lib.MediaInfo_Option(None, "ParseSpeed", str(parse_speed))
-        lib.MediaInfo_Option(None, "LegacyStreamDisplay", "1" if legacy_stream_display else "")
+        lib.MediaInfo_Option(handle, "Inform", "" if text else xml_option)
+        lib.MediaInfo_Option(handle, "Complete", "1" if full else "")
+        lib.MediaInfo_Option(handle, "ParseSpeed", str(parse_speed))
+        lib.MediaInfo_Option(handle, "LegacyStreamDisplay", "1" if legacy_stream_display else "")
+        if mediainfo_options is not None:
+            if lib_version < (19, 9):
+                warnings.warn("This version of MediaInfo ({}) does not support resetting all options to their default values, "
+                    "passing it custom options is not recommended and may result in unpredictable behavior, "
+                    "see https://github.com/MediaArea/MediaInfoLib/issues/1128".format(lib_version_str),
+                    RuntimeWarning
+                )
+            for option_name, option_value in mediainfo_options.items():
+                lib.MediaInfo_Option(handle, option_name, option_value)
         if lib.MediaInfo_Open(handle, filename) == 0:
             raise RuntimeError("An eror occured while opening {}"
                     " with libmediainfo".format(filename))
         output = lib.MediaInfo_Inform(handle, 0)
+        # Reset all options to their defaults so that they aren't
+        # retained when the parse method is called several times
+        # https://github.com/MediaArea/MediaInfoLib/issues/1128
+        if lib_version > (19, 7):
+            lib.MediaInfo_Option(handle, "Reset", "")
         # Delete the handle
         lib.MediaInfo_Close(handle)
         lib.MediaInfo_Delete(handle)
